"use strict";

var _assert = _interopRequireDefault(require("assert"));

var _neatequal = _interopRequireDefault(require("neatequal"));

var _index = require("./index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('index', () => {
  describe('parseWWWAuthenticateHeader', () => {
    it('should parse Basic headers', () => {
      (0, _neatequal.default)((0, _index.parseWWWAuthenticateHeader)('Basic realm="test"'), {
        type: 'Basic',
        data: {
          realm: 'test'
        }
      });
      (0, _neatequal.default)((0, _index.parseWWWAuthenticateHeader)('basic realm="test"', [_index.BASIC], {
        strict: false
      }), {
        type: 'Basic',
        data: {
          realm: 'test'
        }
      });
    });
    it('should parse Bearer headers', () => {
      (0, _neatequal.default)((0, _index.parseWWWAuthenticateHeader)('Bearer realm="test"', _index.mechanisms), {
        type: 'Bearer',
        data: {
          realm: 'test'
        }
      });
      (0, _neatequal.default)((0, _index.parseWWWAuthenticateHeader)('bearer realm="test"', _index.mechanisms, {
        strict: false
      }), {
        type: 'Bearer',
        data: {
          realm: 'test'
        }
      });
    });
    it('should fail with unknown headers', () => {
      _assert.default.throws(() => (0, _index.parseWWWAuthenticateHeader)('Kikoolol realm="test"'), /E_UNKNOWN_AUTH_MECHANISM/);
    });
  });
  describe('parseAuthorizationHeader', () => {
    it('should parse Basic headers', () => {
      (0, _neatequal.default)((0, _index.parseAuthorizationHeader)('Basic QWxpIEJhYmE6b3BlbiBzZXNhbWU='), {
        type: 'Basic',
        data: {
          username: 'Ali Baba',
          password: 'open sesame',
          hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU='
        }
      });
      (0, _neatequal.default)((0, _index.parseAuthorizationHeader)('basic QWxpIEJhYmE6b3BlbiBzZXNhbWU=', [_index.BASIC], {
        strict: false
      }), {
        type: 'Basic',
        data: {
          hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=',
          username: 'Ali Baba',
          password: 'open sesame'
        }
      }, {
        strict: false
      });
      (0, _neatequal.default)((0, _index.parseAuthorizationHeader)('Basic QWxpIEJhYmE6b3BlbiBzZXNhbWU=', _index.mechanisms), {
        type: 'Basic',
        data: {
          username: 'Ali Baba',
          password: 'open sesame',
          hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU='
        }
      });
      (0, _neatequal.default)((0, _index.parseAuthorizationHeader)('Basic bmljb2xhcy5mcm9pZHVyZUBzaW1wbGlmaWVsZC5jb206dGVzdA=='), {
        type: 'Basic',
        data: {
          username: 'nicolas.froidure@simplifield.com',
          password: 'test',
          hash: 'bmljb2xhcy5mcm9pZHVyZUBzaW1wbGlmaWVsZC5jb206dGVzdA=='
        }
      });
    });
    it('should parse Basic headers with a ":" char in the password', () => {
      (0, _neatequal.default)((0, _index.parseAuthorizationHeader)('Basic Sm9objpSOlU6a2lkZGluZz8='), {
        type: 'Basic',
        data: {
          username: 'John',
          password: 'R:U:kidding?',
          hash: 'Sm9objpSOlU6a2lkZGluZz8='
        }
      });
    });
    it('should fail with unknown headers', () => {
      _assert.default.throws(() => (0, _index.parseAuthorizationHeader)('Kikoolol ddd'), /E_UNKNOWN_AUTH_MECHANISM/);
    });
    it('should fail with basic headers in strict mode', () => {
      _assert.default.throws(() => (0, _index.parseAuthorizationHeader)('basic ddd'), /E_UNKNOWN_AUTH_MECHANISM/);

      _assert.default.throws(() => (0, _index.parseAuthorizationHeader)('basic ddd'), /E_UNKNOWN_AUTH_MECHANISM/);

      _assert.default.throws(() => (0, _index.parseAuthorizationHeader)('basic ddd'), /E_UNKNOWN_AUTH_MECHANISM/);
    });
  });
  describe('buildWWWAuthenticateHeader', () => {
    it('should build Basic headers', () => {
      _assert.default.equal((0, _index.buildWWWAuthenticateHeader)(_index.BASIC, {
        realm: 'test'
      }), 'Basic realm="test"');
    });
    it('should be reentrant', () => {
      _assert.default.equal((0, _index.buildWWWAuthenticateHeader)(_index.BASIC, (0, _index.parseWWWAuthenticateHeader)('Basic realm="test"').data), 'Basic realm="test"');
    });
  });
  describe('buildAuthorizationHeader', () => {
    it('should build Basic headers', () => {
      _assert.default.equal((0, _index.buildAuthorizationHeader)(_index.BASIC, {
        username: 'John',
        password: 'R:U:kidding?'
      }), 'Basic Sm9objpSOlU6a2lkZGluZz8=');
    });
    it('should be reentrant', () => {
      _assert.default.equal((0, _index.buildAuthorizationHeader)(_index.BASIC, (0, _index.parseAuthorizationHeader)('Basic Sm9objpSOlU6a2lkZGluZz8=', [_index.BASIC]).data), 'Basic Sm9objpSOlU6a2lkZGluZz8=');
    });
  });
  describe('mechanisms', () => {
    it('should export bot DIGEST and BASIC  mechanisms', () => {
      _assert.default.equal(_index.mechanisms.length, 3);
    });
    it('should export DIGEST BASIC and BEARER mechanisms', () => {
      (0, _assert.default)(_index.BASIC);
      (0, _assert.default)(_index.DIGEST);
      (0, _assert.default)(_index.BEARER);
    });
  });
});
//# sourceMappingURL=index.test.js.map