import YError from 'yerror';
import { parseHTTPHeadersQuotedKeyValueSet, buildHTTPHeadersQuotedKeyValueSet } from '../utils';
const REQUIRED_WWW_AUTHENTICATE_KEYS = ['realm'];
const AUTHORIZED_WWW_AUTHENTICATE_KEYS = REQUIRED_WWW_AUTHENTICATE_KEYS;
const BASIC = {
  type: 'Basic',
  parseWWWAuthenticateRest: function parseWWWAuthenticateRest(rest) {
    return parseHTTPHeadersQuotedKeyValueSet(rest, AUTHORIZED_WWW_AUTHENTICATE_KEYS, REQUIRED_WWW_AUTHENTICATE_KEYS);
  },
  buildWWWAuthenticateRest: function buildWWWAuthenticateRest(data) {
    return buildHTTPHeadersQuotedKeyValueSet(data, AUTHORIZED_WWW_AUTHENTICATE_KEYS, REQUIRED_WWW_AUTHENTICATE_KEYS);
  },
  parseAuthorizationRest: function parseAuthorizationRest(rest) {
    if (!rest) {
      throw new YError('E_EMPTY_AUTH');
    }

    const {
      username,
      password
    } = BASIC.decodeHash(rest);
    return {
      hash: rest,
      username,
      password
    };
  },
  buildAuthorizationRest: function buildAuthorizationRest({
    hash,
    username,
    password
  }) {
    if (username && password) {
      return BASIC.computeHash({
        username,
        password
      });
    }

    if (!hash) {
      throw new YError('E_NO_HASH');
    }

    return hash;
  },
  computeHash: function computeHash({
    username,
    password
  }) {
    return Buffer.from(username + ':' + password).toString('base64');
  },
  decodeHash: function decodeHash(hash) {
    const [username, ...passwordParts] = Buffer.from(hash, 'base64').toString().split(':');
    return {
      username,
      password: passwordParts.join(':')
    };
  }
};
export default BASIC;
//# sourceMappingURL=basic.mjs.map