"use strict";

var _assert = _interopRequireDefault(require("assert"));

var _neatequal = _interopRequireDefault(require("neatequal"));

var _basic = _interopRequireDefault(require("./basic"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('BASIC', () => {
  describe('type', () => {
    test('should be the basic auth prefix', () => {
      _assert.default.equal(_basic.default.type, 'Basic');
    });
  });
  describe('parseWWWAuthenticateRest', () => {
    test('should work', () => {
      (0, _neatequal.default)(_basic.default.parseWWWAuthenticateRest('realm="perlinpinpin"'), {
        realm: 'perlinpinpin'
      });
    });
  });
  describe('buildWWWAuthenticateRest', () => {
    test('should work', () => {
      _assert.default.equal(_basic.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin'
      }), 'realm="perlinpinpin"');
    });
    test('should be the inverse of parseWWWAuthenticateRest', () => {
      (0, _neatequal.default)(_basic.default.parseWWWAuthenticateRest(_basic.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin'
      })), {
        realm: 'perlinpinpin'
      });
    });
  });
  describe('parseAuthorizationRest', () => {
    test('should work', () => {
      (0, _neatequal.default)(_basic.default.parseAuthorizationRest('QWxpIEJhYmE6b3BlbiBzZXNhbWU='), {
        hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=',
        username: 'Ali Baba',
        password: 'open sesame'
      });
      (0, _neatequal.default)(_basic.default.parseAuthorizationRest('bmljb2xhcy5mcm9pZHVyZUBzaW1wbGlmaWVsZC5jb206dGVzdA=='), {
        hash: 'bmljb2xhcy5mcm9pZHVyZUBzaW1wbGlmaWVsZC5jb206dGVzdA==',
        username: 'nicolas.froidure@simplifield.com',
        password: 'test'
      });
    });
    test('should fail with empty rest', () => {
      _assert.default.throws(() => _basic.default.parseAuthorizationRest(''), /E_EMPTY_AUTH/);
    });
  });
  describe('buildAuthorizationRest', () => {
    test('should work with credentials', () => {
      _assert.default.equal(_basic.default.buildAuthorizationRest({
        username: 'Ali Baba',
        password: 'open sesame'
      }), 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=');
    });
    test('should work with just the hash', () => {
      _assert.default.equal(_basic.default.buildAuthorizationRest({
        hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU='
      }), 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=');
    });
    test('should fail with nothing at all', () => {
      _assert.default.throws(() => _basic.default.buildAuthorizationRest({}), /E_NO_HASH/);
    });
    test('should be the inverse of parseAuthorizationRest', () => {
      (0, _neatequal.default)(_basic.default.parseAuthorizationRest(_basic.default.buildAuthorizationRest({
        hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=',
        username: 'Ali Baba',
        password: 'open sesame'
      })), {
        hash: 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=',
        username: 'Ali Baba',
        password: 'open sesame'
      });
    });
  });
  describe('computeHash', () => {
    test('should work', () => {
      _assert.default.equal(_basic.default.computeHash({
        username: 'Ali Baba',
        password: 'open sesame'
      }), 'QWxpIEJhYmE6b3BlbiBzZXNhbWU=');
    });
  });
  describe('decodeHash', () => {
    test('should work', () => {
      (0, _neatequal.default)(_basic.default.decodeHash('QWxpIEJhYmE6b3BlbiBzZXNhbWU='), {
        username: 'Ali Baba',
        password: 'open sesame'
      });
    });
  });
});
//# sourceMappingURL=basic.test.js.map