import YError from 'yerror';
import { parseHTTPHeadersQuotedKeyValueSet, buildHTTPHeadersQuotedKeyValueSet } from '../utils';
const AUTHORIZED_ERROR_CODES = ['invalid_request', 'invalid_token', 'insufficient_scope'];
const REQUIRED_WWW_AUTHENTICATE_KEYS = ['realm'];
const AUTHORIZED_WWW_AUTHENTICATE_KEYS = [...REQUIRED_WWW_AUTHENTICATE_KEYS, 'scope', 'error', 'error_description'];
const BEARER = {
  type: 'Bearer',
  parseWWWAuthenticateRest: function parseWWWAuthenticateRest(rest) {
    return parseHTTPHeadersQuotedKeyValueSet(rest, AUTHORIZED_WWW_AUTHENTICATE_KEYS, []);
  },
  buildWWWAuthenticateRest: function buildWWWAuthenticateRest(data) {
    if (data.error && -1 === AUTHORIZED_ERROR_CODES.indexOf(data.error)) {
      throw new YError('E_INVALID_ERROR', data.error, AUTHORIZED_ERROR_CODES);
    }

    return buildHTTPHeadersQuotedKeyValueSet(data, AUTHORIZED_WWW_AUTHENTICATE_KEYS, []);
  },
  parseAuthorizationRest: function parseAuthorizationRest(rest) {
    if (!rest) {
      throw new YError('E_EMPTY_AUTH');
    }

    return {
      hash: rest
    };
  },
  buildAuthorizationRest: function buildAuthorizationRest({
    hash
  }) {
    if (!hash) {
      throw new YError('E_NO_HASH');
    }

    return hash;
  }
};
export default BEARER;
//# sourceMappingURL=bearer.mjs.map