"use strict";

var _assert = _interopRequireDefault(require("assert"));

var _neatequal = _interopRequireDefault(require("neatequal"));

var _bearer = _interopRequireDefault(require("./bearer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('BEARER', () => {
  describe('type', () => {
    it('should be the basic auth prefix', () => {
      _assert.default.equal(_bearer.default.type, 'Bearer');
    });
  });
  describe('parseWWWAuthenticateRest', () => {
    it('should work', () => {
      (0, _neatequal.default)(_bearer.default.parseWWWAuthenticateRest('realm="perlinpinpin"'), {
        realm: 'perlinpinpin'
      });
    });
  });
  describe('buildWWWAuthenticateRest', () => {
    it('should work', () => {
      _assert.default.equal(_bearer.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin'
      }), 'realm="perlinpinpin"');
    });
    it('should work with an error', () => {
      _assert.default.equal(_bearer.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin',
        error: 'invalid_request',
        error_description: 'The access token expired'
      }), 'realm="perlinpinpin", ' + 'error="invalid_request", ' + 'error_description="The access token expired"');
    });
    it('should fail with an unauthorized error', () => {
      _assert.default.throws(() => _bearer.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin',
        error: 'invalid_tacos',
        error_description: 'The tacos has been eaten yet'
      }), /E_INVALID_ERROR/);
    });
    it('should be the inverse of parseWWWAuthenticateRest', () => {
      (0, _neatequal.default)(_bearer.default.parseWWWAuthenticateRest(_bearer.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin'
      })), {
        realm: 'perlinpinpin'
      });
    });
  });
  describe('parseAuthorizationRest', () => {
    it('should work', () => {
      (0, _neatequal.default)(_bearer.default.parseAuthorizationRest('mF_9.B5f-4.1JqM'), {
        hash: 'mF_9.B5f-4.1JqM'
      });
    });
    it('should fail with empty rest', () => {
      _assert.default.throws(() => _bearer.default.parseAuthorizationRest(''), /E_EMPTY_AUTH/);
    });
  });
  describe('buildAuthorizationRest', () => {
    it('should work', () => {
      _assert.default.equal(_bearer.default.buildAuthorizationRest({
        hash: 'mF_9.B5f-4.1JqM'
      }), 'mF_9.B5f-4.1JqM');
    });
    it('should fail with nothing at all', () => {
      _assert.default.throws(() => _bearer.default.buildAuthorizationRest({}), /E_NO_HASH/);
    });
    it('should be the inverse of parseAuthorizationRest', () => {
      (0, _neatequal.default)(_bearer.default.parseAuthorizationRest(_bearer.default.buildAuthorizationRest({
        hash: 'mF_9.B5f-4.1JqM'
      })), {
        hash: 'mF_9.B5f-4.1JqM'
      });
    });
  });
});
//# sourceMappingURL=bearer.test.js.map