"use strict";

var _assert = _interopRequireDefault(require("assert"));

var _neatequal = _interopRequireDefault(require("neatequal"));

var _digest = _interopRequireDefault(require("./digest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('digest', () => {
  describe('type', () => {
    it('should be the digest auth prefix', () => {
      _assert.default.equal(_digest.default.type, 'Digest');
    });
  });
  describe('parseWWWAuthenticateRest', () => {
    it('should work', () => {
      (0, _neatequal.default)(_digest.default.parseWWWAuthenticateRest('realm="testrealm@host.com", ' + 'qop="auth, auth-int", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093", ' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41"'), {
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      });
    });
    it('should handle non-quoted fields', () => {
      (0, _neatequal.default)(_digest.default.parseWWWAuthenticateRest('realm="testrealm@host.com", ' + 'qop=auth, ' + 'algorithm=MD5, ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093"'), {
        realm: 'testrealm@host.com',
        qop: 'auth',
        algorithm: 'MD5',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093'
      });
    });
  });
  describe('buildWWWAuthenticateRest', () => {
    it('should work', () => {
      _assert.default.equal(_digest.default.buildWWWAuthenticateRest({
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      }), 'realm="testrealm@host.com", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093", ' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41", ' + 'qop="auth, auth-int"');
    });
    it('should be the inverse of parseWWWAuthenticateRest', () => {
      (0, _neatequal.default)(_digest.default.parseWWWAuthenticateRest(_digest.default.buildWWWAuthenticateRest({
        realm: 'perlinpinpin',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093'
      })), {
        realm: 'perlinpinpin',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093'
      });
    });
  });
  describe('parseAuthorizationRest', () => {
    it('should work', () => {
      (0, _neatequal.default)(_digest.default.parseAuthorizationRest('username="Mufasa",' + 'realm="testrealm@host.com",' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093",' + 'uri="/dir/index.html",' + 'qop="auth",' + 'nc="00000001",' + 'cnonce="0a4f113b",' + 'response="6629fae49393a05397450978507c4ef1",' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41"'), {
        username: 'Mufasa',
        realm: 'testrealm@host.com',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        uri: '/dir/index.html',
        qop: 'auth',
        nc: '00000001',
        cnonce: '0a4f113b',
        response: '6629fae49393a05397450978507c4ef1',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      });
    });
    it('should fail with empty rest', () => {
      _assert.default.throws(() => _digest.default.parseAuthorizationRest(''), /E_MALFORMED_QUOTEDKEYVALUE/);
    });
  });
  describe('buildAuthorizationRest', () => {
    it('should work', () => {
      _assert.default.equal(_digest.default.buildAuthorizationRest({
        username: 'Mufasa',
        realm: 'testrealm@host.com',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        uri: '/dir/index.html',
        qop: 'auth',
        nc: '00000001',
        cnonce: '0a4f113b',
        response: '6629fae49393a05397450978507c4ef1',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      }), 'username="Mufasa", ' + 'realm="testrealm@host.com", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093", ' + 'uri="/dir/index.html", ' + 'response="6629fae49393a05397450978507c4ef1", ' + 'cnonce="0a4f113b", ' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41", ' + 'qop="auth", ' + 'nc="00000001"');
    });
    it('should be the inverse of parseAuthorizationRest', () => {
      (0, _neatequal.default)(_digest.default.parseAuthorizationRest(_digest.default.buildAuthorizationRest({
        username: 'Mufasa',
        realm: 'testrealm@host.com',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        uri: '/dir/index.html',
        qop: 'auth',
        nc: '00000001',
        cnonce: '0a4f113b',
        response: '6629fae49393a05397450978507c4ef1',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      })), {
        username: 'Mufasa',
        realm: 'testrealm@host.com',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        uri: '/dir/index.html',
        qop: 'auth',
        nc: '00000001',
        cnonce: '0a4f113b',
        response: '6629fae49393a05397450978507c4ef1',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      });
    });
  });
  describe('computeHash', () => {
    it('should work', () => {
      _assert.default.equal(_digest.default.computeHash({
        username: 'Mufasa',
        realm: 'testrealm@host.com',
        password: 'Circle Of Life',
        method: 'GET',
        uri: '/dir/index.html',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        nc: '00000001',
        cnonce: '0a4f113b',
        qop: 'auth',
        algorithm: 'md5'
      }), '6629fae49393a05397450978507c4ef1');
    });
  });
});
//# sourceMappingURL=digest.test.js.map