import YError from 'yerror';
const QUOTE = '"';
const EQUAL = '=';
const SEPARATOR = ', ';
const KEYVALUE_REGEXP = /\w+=(".*?"|[^",]+)(?=,|$)/g;
export function parseHTTPHeadersQuotedKeyValueSet(contents, authorizedKeys, requiredKeys = []) {
  const matches = contents.trim().match(KEYVALUE_REGEXP);
  if (!matches) throw new YError('E_MALFORMED_QUOTEDKEYVALUE', contents);
  const data = matches.map((part, partPosition) => {
    const pair = part.split(EQUAL);

    if (2 !== pair.length) {
      throw new YError('E_MALFORMED_QUOTEDKEYVALUE', partPosition, part, pair.length);
    }

    return pair;
  }).reduce(function (parsedValues, [name, value], valuePosition) {
    if (-1 === authorizedKeys.indexOf(name)) {
      throw new YError('E_UNAUTHORIZED_KEY', valuePosition, name);
    }

    parsedValues[name] = value.replace(/^"(.+(?="$))"$/, '$1');
    return parsedValues;
  }, {});

  _checkRequiredKeys(requiredKeys, data);

  return data;
}
export function buildHTTPHeadersQuotedKeyValueSet(data, authorizedKeys, requiredKeys = []) {
  _checkRequiredKeys(requiredKeys, data);

  return authorizedKeys.reduce(function (contents, key) {
    if (data[key]) {
      return contents + (contents ? SEPARATOR : '') + key + EQUAL + QUOTE + data[key] + QUOTE;
    }

    return contents;
  }, '');
}

function _checkRequiredKeys(requiredKeys, data) {
  requiredKeys.forEach(name => {
    if ('undefined' === typeof data[name]) {
      throw new YError('E_REQUIRED_KEY', name);
    }
  });
}
//# sourceMappingURL=utils.mjs.map