"use strict";

var _assert = _interopRequireDefault(require("assert"));

var _neatequal = _interopRequireDefault(require("neatequal"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('utils', () => {
  describe('parseHTTPHeadersQuotedKeyValueSet', () => {
    test('should work with good datas', () => {
      (0, _neatequal.default)((0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm="testrealm@host.com", ' + 'qop="auth, auth-int", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093", ' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41"', ['realm', 'qop', 'nonce', 'opaque'], ['realm', 'qop', 'nonce', 'opaque']), {
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      });
    });
    test('should work with parse-able non-quoted data', () => {
      (0, _neatequal.default)((0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm="testrealm@host.com", ' + 'qop=auth, ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093", ' + 'opaque="5ccc069c403ebaf9f0171e9517f40e41"', ['realm', 'qop', 'nonce', 'opaque'], ['realm', 'qop', 'nonce', 'opaque']), {
        realm: 'testrealm@host.com',
        qop: 'auth',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      });
    });
    test('should fail with bad quoted value pair', () => {
      _assert.default.throws(() => (0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm', []), /E_MALFORMED_QUOTEDKEYVALUE/);
    });
    test('should fail with half-quoted value pair', () => {
      _assert.default.throws(() => (0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm="uneven', ['realm']), /E_MALFORMED_QUOTEDKEYVALUE/);
    });
    test('should fail with bad quoted value pair', () => {
      _assert.default.throws(() => (0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm="dsad"', []), /E_UNAUTHORIZED_KEY/);
    });
    test('should pass with non-quoted value pair', () => {
      (0, _neatequal.default)((0, _utils.parseHTTPHeadersQuotedKeyValueSet)('realm=dsad', ['realm']), {
        realm: 'dsad'
      });
    });
  });
  describe('buildHTTPHeadersQuotedKeyValueSet', () => {
    test('should work with good datas', () => {
      _assert.default.equal((0, _utils.buildHTTPHeadersQuotedKeyValueSet)({
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093'
      }, ['realm', 'qop', 'nonce', 'opaque'], ['realm', 'qop', 'nonce']), 'realm="testrealm@host.com", ' + 'qop="auth, auth-int", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093"');
    });
    test('should work with unused keys', () => {
      _assert.default.equal((0, _utils.buildHTTPHeadersQuotedKeyValueSet)({
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int',
        nonce: 'dcd98b7102dd2f0e8b11d0f600bfb0c093',
        opaque: '5ccc069c403ebaf9f0171e9517f40e41'
      }, ['realm', 'qop', 'nonce']), 'realm="testrealm@host.com", ' + 'qop="auth, auth-int", ' + 'nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093"');
    });
    test('should fail without required keys', () => {
      _assert.default.throws(() => (0, _utils.buildHTTPHeadersQuotedKeyValueSet)({
        realm: 'testrealm@host.com',
        qop: 'auth, auth-int'
      }, ['realm', 'qop', 'nonce'], ['realm', 'qop', 'nonce']), /E_REQUIRED_KEY/);
    });
  });
});
//# sourceMappingURL=utils.test.js.map